==> haskell-newtype-generics-0.5.3-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: newtype-generics
version: 0.5.3
id: newtype-generics-0.5.3-FsCR18lfQ5WAUHVNCXYRex
key: newtype-generics-0.5.3-FsCR18lfQ5WAUHVNCXYRex
license: BSD-3-Clause
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.
category: Control
abi: 6f218b4a8cf4b0b5e142f95f01099d8e
exposed: True
exposed-modules:
    Control.Newtype Control.Newtype.Generics
import-dirs: /usr/lib/ghc-8.4.3/site-local/newtype-generics-0.5.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/newtype-generics-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/newtype-generics-0.5.3
hs-libraries: HSnewtype-generics-0.5.3-FsCR18lfQ5WAUHVNCXYRex
depends:
    base-4.11.1.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock
haddock-html: /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-newtype-generics-0.5.3-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: newtype-generics
version: 0.5.3
id: newtype-generics-0.5.3-68qb6BYyUFhFUwvEOd40Rb
key: newtype-generics-0.5.3-68qb6BYyUFhFUwvEOd40Rb
license: BSD-3-Clause
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.
category: Control
abi: 042f8b253273e3a0dfb13c69b2c25631
exposed: True
exposed-modules:
    Control.Newtype Control.Newtype.Generics
import-dirs: /usr/lib/ghc-8.4.3/site-local/newtype-generics-0.5.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/newtype-generics-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/newtype-generics-0.5.3
hs-libraries: HSnewtype-generics-0.5.3-68qb6BYyUFhFUwvEOd40Rb
depends:
    base-4.11.1.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock
haddock-html: /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
